@@ -1,5 +1,5 @@
 from abc import ABC
-from typing import Any, Dict, TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Dict
 
 from pymongo import MongoClient
 
