@@ -1,6 +1,6 @@
 import os
 import sys
-from io import StringIO, BytesIO
+from io import BytesIO, StringIO
 from typing import TYPE_CHECKING
 
 import botocore
@@ -465,3 +465,21 @@ class S3Connector(ILogger):
         bucket = self.s3_resource.Bucket(destination_bucket_name)  # type: ignore[union-attr]
         bucket.copy(copy_source, destination_key)
         return True
+
+    def change_lifecycle_configuration(self, lifecycle_configuration: "Dict[str, Any]") -> None:
+        self.s3_client.put_bucket_lifecycle_configuration(
+            Bucket=self.bucket_name, LifecycleConfiguration=lifecycle_configuration
+        )
+
+    def set_expiration_for_prefix(self, prefix: str, days_to_expiration: int) -> None:
+        lifecycle_configuration = {
+            "Rules": [
+                {
+                    "Expiration": {"Days": days_to_expiration},
+                    "Filter": {"Prefix": prefix},
+                    "ID": f"Expiration for {self.bucket_name}/{prefix}",
+                    "Status": "Enabled",
+                }
+            ]
+        }
+        self.change_lifecycle_configuration(lifecycle_configuration=lifecycle_configuration)
