@@ -1,16 +1,15 @@
 import os
-import gdown  # type: ignore[import]
-import socket
-import zipfile
 import os.path
+import socket
 import tempfile
 import urllib.error
-from uuid import uuid4
+import zipfile
 from typing import Any, Optional
 from urllib.parse import urlparse
 from urllib.request import urlretrieve
+from uuid import uuid4
 
-# This timeout should be big, because InferenceSimulator run take a long time.
+import gdown  # type: ignore[import]
 import requests
 from cryptography.fernet import Fernet, InvalidToken
 
@@ -109,13 +108,6 @@ class FilesDataInterface:
         if "drive.google.com" in file_url:
             FilesDataInterface._download_google_drive_file(file_url, file_path)
         else:
-            if "www.dropbox.com" in file_url:
-                # Adding dl=1 for dropbox to download the file raw (without html page)
-                if "dl=0" not in file_url:
-                    file_url += "?dl=1"
-                else:
-                    file_url = file_url.replace("dl=0", "dl=1")
-
             # TODO: Use requests with stream and limit the file size and timeouts.
             socket.setdefaulttimeout(timeout_seconds)
             try:
@@ -151,13 +143,6 @@ class FilesDataInterface:
         except Exception as ex:
             raise FileDownloadFailedException("File download did not finish correctly " + str(ex))
 
-    # FIXME - DECIDE ON THE CLEANUP METHOD - MAKE SURE IT WORKS WELL WITH STATIC METHODS
-    # def __del__(self):
-    #     """
-    #     Cleaning the urls downloaded via urlretrieve (_download_temporary_file)
-    #     """
-    #     urlcleanup()
-
     @staticmethod
     def encrypt_file(file: bytes, key: bytes) -> bytes:
         """
