@@ -1,7 +1,7 @@
-from typing import Generic, TYPE_CHECKING, TypeVar
+from typing import TYPE_CHECKING, Generic, TypeVar
 
-from deci_common.abstractions.base_model import DBSchema
 from deci_common.abstractions.abstract_logger import ILogger
+from deci_common.abstractions.base_model import DBSchema
 
 if TYPE_CHECKING:
     from typing import Any, Dict, List, Optional, Type
